#
# spec file for package libqt5-qtscript
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
%define libname libQt5Script5
%define base_name libqt5
%define real_version 5.15.15
%define so_version 5.15.15
%define tar_version qtscript-everywhere-src-%{version}
Name:           libqt5-qtscript
Version:        5.15.15
Release:        1.2
Summary:        Qt 5 Script library
# Legal:
# Most files in src/script are LGPL-2.1-only
# src/3rdparty is LGPL-2.0-or-later + BSD == LGPL-2.0-or-later
License:        (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-or-later) AND LGPL-2.0-or-later AND LGPL-2.1-only
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM libqt5-qtscript-s390-support.patch -- adds s390, taken from webkit upstream
Patch3:         libqt5-qtscript-s390-support.patch
BuildRequires:  libQt5Core-private-headers-devel >= 5.15
BuildRequires:  libQt5Widgets-private-headers-devel >= 5.15
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5DBus) >= 5.15
BuildRequires:  pkgconfig(Qt5Gui) >= 5.15
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.15

%description
Qt Script is a module for adding scripting to applications. It allows
evaluating and debugging of scripts, and advanced use of objects and
functions. It also gives access to a low-level ECMAScript engine API.

%prep
%autosetup -p1 -n %{tar_version}

%package -n %{libname}
Summary:        Qt 5 Script library
Group:          System/Libraries
%requires_ge    libQt5Widgets5

%description -n %{libname}
Qt Script is a module for adding scripting to applications. It allows
evaluating and debugging of scripts, and advanced use of objects and
functions. It also gives access to a low-level ECMAScript engine API.

%package devel
Summary:        Development files for the Qt 5 Script library
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}
Provides:       libQt5Script-devel = %{version}
Obsoletes:      libQt5Script-devel < %{version}

%description devel
Qt Script is a module for adding scripting to applications.

This subpackage contains the header files for developing
applications that want to make use of libQt5Script5.

%package private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 Script library
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
%requires_eq libQt5Core-private-headers-devel
%requires_eq libQt5Widgets-private-headers-devel
Provides:       libQt5Script-private-headers-devel = %{version}
Obsoletes:      libQt5Script-private-headers-devel < %{version}
BuildArch:      noarch

%description private-headers-devel
This package provides private headers of libqt5-qtscript that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 Script examples
Group:          Documentation/Other
License:        BSD-3-Clause
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtscript module.

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%build
%define _lto_cflags %{nil}
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
find %{buildroot}/%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} +
find %{buildroot}/%{_libdir} -type f -name '*pc' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} + -exec sed -i -e "s,^moc_location=.*,moc_location=%{_libqt5_bindir}/moc," -e "s,uic_location=.*,uic_location=%{_libqt5_bindir}/uic," {} +
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%files -n %{libname}
%license LICENSE.*
%{_libqt5_libdir}/libQt5*.so.*

%files private-headers-devel
%{_libqt5_includedir}/Qt*/%{so_version}

%files devel
%exclude %{_libqt5_includedir}/Qt*/%{so_version}
%{_libqt5_includedir}/Qt*
%{_libqt5_libdir}/cmake/Qt5*
%{_libqt5_libdir}/libQt5*.prl
%{_libqt5_libdir}/libQt5*.so
%{_libqt5_libdir}/pkgconfig/Qt5*.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_*.pri

%files examples
%{_libqt5_examplesdir}/

%changelog
* Fri Oct  6 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.15:
  * Bump version to 5.15.15
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14:
  * Bump version to 5.15.14
  * Bump version to 5.15.13
* Wed Jan 11 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde0, rebased upstream:
  * Bump version to 5.15.12
  * Bump version to 5.15.11
- Use origin/ in the _service file to work around some weirdness
  in obs_scm
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde0, rebased upstream:
  * No code changes
- Commits dropped by the rebase:
  * Bump version to 5.15.10
  * Blacklist two tests that fail on macOS ARM
  * Bump version from 5.15.8 to 5.15.9
  * Bump version from 5.15.7 to 5.15.8
  * Bump version from 5.15.6 to 5.15.7
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10:
  * Bump version to 5.15.10
  * Blacklist two tests that fail on macOS ARM
  * Bump version from 5.15.8 to 5.15.9
  * Bump version from 5.15.7 to 5.15.8
  * Bump version from 5.15.6 to 5.15.7
  * Bump version from 5.15.5 to 5.15.6
  * Bump version from 5.15.4 to 5.15.5
- Drop patches, it's versioned correctly now:
  * 0001-Revert-Bump-version-from-5.15.3-to-5.15.4.patch
  * 0002-Revert-Bump-version.patch
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde4:
  * Bump version from 5.15.3 to 5.15.4
  * Add product_dependencies.yaml to build against LTS 5.15
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patches to reset version to 5.15.2:
  * 0001-Revert-Bump-version-from-5.15.3-to-5.15.4.patch
  * 0002-Revert-Bump-version.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Sun Dec 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Remove unneeded parentheses in license tag
* Tue Dec 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtscript.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtscript.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Tue May 14 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133241).
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.12.2/?h=5.12.2
- Remove patches, now upstream:
  * libqt5-qtscript-toplevel-asm.patch
- Use %%license
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Wed Jan  9 2019 rguenther@suse.com
- Add libqt5-qtscript-toplevel-asm.patch to adhere to stricter
  toplevel asm parsing, dropping volatile qualification that has no
  effect.
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
- Refresh libqt5-qtscript-s390-support.patch
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtscript.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtscript.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- TODO: QTBUG-63415
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Mon Sep 11 2017 jengelh@inai.de
- Update descriptions.
- Update find calls to use the "+" strategy.
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
- Drop  ppc64le-support.patch, merged upstream
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Add minimal requires on libQt5Widgets5
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (r11ca348):
  * Tip of the bugfix 5.3.2 branch:
  * Work around ICC optimizer bug hoisting conditions
    out of the loop
  * Fix crash when creating a QScriptEngine in a native thread
  * Bump version
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
- Drop aarch64-support.patch, merged upstream
- Rebase libqt5-qtscript-s390-support.patch for this release
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Build, and add examples subpackage
* Fri Mar  7 2014 mlin@suse.com
- Add libqt5-qtscript-s390-support.patch
  * add s390(x) support
* Mon Feb 10 2014 mlin@suse.com
- Install LICENSE files to %%doc
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Remove libtool archives from packages
- Added aarch64-support.patch from upstream (merged for 5.3)
* Mon Dec 16 2013 uweigand@de.ibm.com
- Add ppc64le-support.patch: Support powerpc64le-linux.
* Mon Dec 16 2013 hrvoje.senjan@gmail.com
- Make devel and private headers subpackages have consistent naming
  with the rest of Qt 5 subpackages
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Update to 5.2.0 final:
  * For more details please see:
    http://blog.qt.digia.com/blog/2013/12/12/qt-5-2-released-the-best-qt-yet/
    http://qt-project.org/qt5/qt52
    http://qt.digia.com/Product/Whats-New/Qt-52/
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 5.2 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-5-2-release-candidate-1-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Wed Oct 23 2013 hrvoje.senjan@gmail.com
- Update to 5.2 beta1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/10/23/qt-5-2-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Update to version 5.1.1:
  * Bugfix release, please see
  http://blog.qt.digia.com/blog/2013/08/28/qt-5-1-1-released/
  http://qt.gitorious.org/qt/qtscript/blobs/release/dist/changes-5.1.1
  and http://qt-project.org/wiki/Qt511KnownIssues for known issues
- Small spec cleanup
* Sat Aug  3 2013 tittiatcoke@gmail.com
- Adjust package naming according to openSUSE standards
* Sun Jul  7 2013 stephan.binner@basyskom.com
- update to Qt 5.1 release
* Tue Jun 18 2013 stephan.binner@basyskom.com
- update to Qt 5.1 RC 1
* Mon May 20 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Beta 1
* Tue Apr  9 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Alpha 1
* Wed Jan 30 2013 stephan.binner@basyskom.com
- update to Qt 5.0.1
* Wed Dec 19 2012 stephan.binner@basyskom.com
- update to Qt 5.0 release
* Thu Dec 13 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 2
* Thu Dec  6 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 1
* Thu Nov 15 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 2
* Thu Aug 30 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 1 release
* Thu May 24 2012 stephan.binner@basyskom.com
- update to newer Alpha snapshot / Beta candidate
* Fri Apr 13 2012 stephan.binner@basyskom.com
- rework package splitting for Qt 5 modularization
* Thu Apr  5 2012 dmueller@suse.com
- Initial packaging (Qt 5.0 Alpha)
